[前][次][番号順一覧][スレッド一覧]

ruby-changes:21002

From: ngoto <ko1@a...>
Date: Thu, 25 Aug 2011 01:41:20 +0900 (JST)
Subject: [ruby-changes:21002] ngoto:r33051 (trunk): * test/fileutils/test_fileutils.rb (test_chmod_symbol_mode): Solaris

ngoto	2011-08-25 01:41:12 +0900 (Thu, 25 Aug 2011)

  New Revision: 33051

  http://svn.ruby-lang.org/cgi-bin/viewvc.cgi?view=rev&revision=33051

  Log:
    * test/fileutils/test_fileutils.rb (test_chmod_symbol_mode): Solaris
      seems to behave the same as FreeBSD.

  Modified files:
    trunk/ChangeLog
    trunk/test/fileutils/test_fileutils.rb

Index: ChangeLog
===================================================================
--- ChangeLog	(revision 33050)
+++ ChangeLog	(revision 33051)
@@ -1,3 +1,8 @@
+Thu Aug 25 01:24:33 2011  Naohisa Goto  <ngotogenome@g...>
+
+	* test/fileutils/test_fileutils.rb (test_chmod_symbol_mode): Solaris
+	  seems to behave the same as FreeBSD.
+
 Thu Aug 25 01:11:36 2011  Naohisa Goto  <ngotogenome@g...>
 
 	* test/ruby/test_rubyoptions.rb (test_script_from_stdin): slave pty
Index: test/fileutils/test_fileutils.rb
===================================================================
--- test/fileutils/test_fileutils.rb	(revision 33050)
+++ test/fileutils/test_fileutils.rb	(revision 33051)
@@ -913,8 +913,8 @@
     # FreeBSD ufs and tmpfs don't allow to change sticky bit against
     # regular file. It's slightly strange. Anyway it's no effect bit.
     # see /usr/src/sys/ufs/ufs/ufs_chmod()
-    # NetBSD and OpenBSD also denies it.
-    if /freebsd|netbsd|openbsd/ !~ RUBY_PLATFORM
+    # NetBSD, OpenBSD and Solaris also denies it.
+    if /freebsd|netbsd|openbsd|solaris/ !~ RUBY_PLATFORM
       chmod "u+t,o+t", 'tmp/a'
       assert_equal 07500, File.stat('tmp/a').mode & 07777
       chmod "a-t,a-s", 'tmp/a'

--
ML: ruby-changes@q...
Info: http://www.atdot.net/~ko1/quickml/

[前][次][番号順一覧][スレッド一覧]